Improve this Doc View Source

Nestable alias of `form` directive. HTML does not allow nesting of form elements. It is useful to nest forms, for example if the validity of a sub-group of controls needs to be determined.

Note: the purpose of `ngForm` is to group controls, but not to be a replacement for the `<form>` tag with all of its capabilities (e.g. posting to the server, ...).

## Directive Info

- This directive executes at priority level 0.

## Usage

- as element:

      <ng-form
        [name="string"]>
      ...
      </ng-form>

- as attribute:

      <ANY
        [ng-form="string"]>
      ...
      </ANY>

- as CSS class:

      <ANY class="[ng-form: string;]"> ... </ANY>

### Arguments

Param | Type | Details
--- | --- | ---
ngForm | name (optional) | string | Name of the form. If specified, the form controller will be published into related scope, under this name.